from typing import TYPE_CHECKING, List, Optional

from cozepy.audio.voiceprint_groups.features import UserInfo
from cozepy.files import FileTypes, _try_fix_file
from cozepy.model import AsyncNumberPaged, CozeModel, HTTPRequest, NumberPaged, NumberPagedResponse
from cozepy.request import Requester
from cozepy.util import remove_none_values, remove_url_trailing_slash

if TYPE_CHECKING:
    from .features import AsyncVoiceprintGroupsFeaturesClient, VoiceprintGroupsFeaturesClient


class CreateVoicePrintGroupResp(CozeModel):
    id: str


class UpdateVoicePrintGroupResp(CozeModel):
    pass


class DeleteVoicePrintGroupResp(CozeModel):
    pass


class VoicePrintGroup(CozeModel):
    id: str
    name: str
    desc: str
    created_at: int
    updated_at: int
    icon_url: str
    feature_count: int
    user_info: UserInfo


class FeatureScore(CozeModel):
    feature_id: str
    feature_name: str
    feature_desc: str
    score: float


class SpeakerIdentifyResp(CozeModel):
    feature_score_list: List[FeatureScore]


class _PrivateListVoicePrintGroupData(CozeModel, NumberPagedResponse[VoicePrintGroup]):
    items: List[VoicePrintGroup]
    total: int

    def get_total(self) -> Optional[int]:
        return self.total

    def get_has_more(self) -> Optional[bool]:
        return None

    def get_items(self) -> List[VoicePrintGroup]:
        return self.items


class VoiceprintGroupsClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

        self._features: Optional[VoiceprintGroupsFeaturesClient] = None

    @property
    def features(self) -> "VoiceprintGroupsFeaturesClient":
        if self._features is None:
            from .features import VoiceprintGroupsFeaturesClient

            self._features = VoiceprintGroupsFeaturesClient(base_url=self._base_url, requester=self._requester)
        return self._features

    def create(
        self,
        *,
        name: str,
        desc: Optional[str] = None,
        **kwargs,
    ) -> CreateVoicePrintGroupResp:
        url = f"{self._base_url}/v1/audio/voiceprint_groups"
        headers: Optional[dict] = kwargs.get("headers")
        body = remove_none_values(
            {
                "name": name,
                "desc": desc,
            }
        )

        return self._requester.request("post", url, False, cast=CreateVoicePrintGroupResp, headers=headers, body=body)

    def update(
        self,
        *,
        group_id: str,
        name: Optional[str] = None,
        desc: Optional[str] = None,
        **kwargs,
    ) -> UpdateVoicePrintGroupResp:
        url = f"{self._base_url}/v1/audio/voiceprint_groups/{group_id}"
        headers: Optional[dict] = kwargs.get("headers")
        body = remove_none_values(
            {
                "name": name,
                "desc": desc,
            }
        )

        return self._requester.request("put", url, False, cast=UpdateVoicePrintGroupResp, headers=headers, body=body)

    def delete(
        self,
        *,
        group_id: str,
        **kwargs,
    ) -> DeleteVoicePrintGroupResp:
        url = f"{self._base_url}/v1/audio/voiceprint_groups/{group_id}"
        headers: Optional[dict] = kwargs.get("headers")

        return self._requester.request("delete", url, False, cast=DeleteVoicePrintGroupResp, headers=headers)

    def list(
        self,
        *,
        name: Optional[str] = None,
        group_id: Optional[str] = None,
        user_id: Optional[str] = None,
        page_num: int = 1,
        page_size: int = 10,
    ) -> NumberPaged[VoicePrintGroup]:
        """
        Get available voices, including system voices + user cloned voices
        Tips: Voices cloned under each Volcano account can be reused within the team

        :param filter_system_voice: If True, system voices will not be returned.
        :param page_num: The page number for paginated queries. Default is 1, meaning the data return starts from the
        first page.
        :param page_size: The size of pagination. Default is 100, meaning that 100 data entries are returned per page.
        :return: list of Voice
        """
        url = f"{self._base_url}/v1/audio/voiceprint_groups"

        def request_maker(i_page_num: int, i_page_size: int) -> HTTPRequest:
            return self._requester.make_request(
                "GET",
                url,
                params=remove_none_values(
                    {
                        "name": name,
                        "group_id": group_id,
                        "user_id": user_id,
                        "page_num": i_page_num,
                        "page_size": i_page_size,
                    }
                ),
                cast=_PrivateListVoicePrintGroupData,
                stream=False,
            )

        return NumberPaged(
            page_num=page_num,
            page_size=page_size,
            requestor=self._requester,
            request_maker=request_maker,
        )

    def speaker_identify(
        self,
        *,
        group_id: str,
        file: FileTypes,
        top_k: Optional[int] = None,
        sample_rate: Optional[int] = None,
        channel: Optional[int] = None,
        **kwargs,
    ) -> SpeakerIdentifyResp:
        url = f"{self._base_url}/v1/audio/voiceprint_groups/{group_id}/speaker_identify"
        headers: Optional[dict] = kwargs.get("headers")
        files = {"file": _try_fix_file(file)}
        body = remove_none_values(
            {
                "top_k": top_k,
                "sample_rate": sample_rate,
                "channel": channel,
            }
        )

        return self._requester.request(
            "post", url, False, cast=SpeakerIdentifyResp, headers=headers, body=body, files=files
        )


class AsyncVoiceprintGroupsClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

        self._features: Optional[AsyncVoiceprintGroupsFeaturesClient] = None

    @property
    def features(self) -> "AsyncVoiceprintGroupsFeaturesClient":
        if self._features is None:
            from .features import AsyncVoiceprintGroupsFeaturesClient

            self._features = AsyncVoiceprintGroupsFeaturesClient(base_url=self._base_url, requester=self._requester)
        return self._features

    async def create(
        self,
        *,
        name: str,
        desc: Optional[str] = None,
        **kwargs,
    ) -> CreateVoicePrintGroupResp:
        url = f"{self._base_url}/v1/audio/voiceprint_groups"
        headers: Optional[dict] = kwargs.get("headers")
        body = remove_none_values(
            {
                "name": name,
                "desc": desc,
            }
        )

        return await self._requester.arequest(
            "post", url, False, cast=CreateVoicePrintGroupResp, headers=headers, body=body
        )

    async def update(
        self,
        *,
        group_id: str,
        name: Optional[str] = None,
        desc: Optional[str] = None,
        **kwargs,
    ) -> UpdateVoicePrintGroupResp:
        url = f"{self._base_url}/v1/audio/voiceprint_groups/{group_id}"
        headers: Optional[dict] = kwargs.get("headers")
        body = remove_none_values(
            {
                "name": name,
                "desc": desc,
            }
        )

        return await self._requester.arequest(
            "put", url, False, cast=UpdateVoicePrintGroupResp, headers=headers, body=body
        )

    async def delete(
        self,
        *,
        group_id: str,
        **kwargs,
    ) -> DeleteVoicePrintGroupResp:
        url = f"{self._base_url}/v1/audio/voiceprint_groups/{group_id}"
        headers: Optional[dict] = kwargs.get("headers")

        return await self._requester.arequest("delete", url, False, cast=DeleteVoicePrintGroupResp, headers=headers)

    async def list(
        self,
        *,
        name: Optional[str] = None,
        group_id: Optional[str] = None,
        user_id: Optional[str] = None,
        page_num: int = 1,
        page_size: int = 100,
    ) -> AsyncNumberPaged[VoicePrintGroup]:
        """
        Get available voices, including system voices + user cloned voices
        Tips: Voices cloned under each Volcano account can be reused within the team

        :param filter_system_voice: If True, system voices will not be returned.
        :param page_num: The page number for paginated queries. Default is 1, meaning the data return starts from the
        first page.
        :param page_size: The size of pagination. Default is 100, meaning that 100 data entries are returned per page.
        :return: list of Voice
        """
        url = f"{self._base_url}/v1/audio/voiceprint_groups"

        async def request_maker(i_page_num: int, i_page_size: int) -> HTTPRequest:
            return await self._requester.amake_request(
                "GET",
                url,
                params=remove_none_values(
                    {
                        "name": name,
                        "group_id": group_id,
                        "user_id": user_id,
                        "page_num": i_page_num,
                        "page_size": i_page_size,
                    }
                ),
                cast=_PrivateListVoicePrintGroupData,
                stream=False,
            )

        return await AsyncNumberPaged.build(
            page_num=page_num,
            page_size=page_size,
            requestor=self._requester,
            request_maker=request_maker,
        )

    async def speaker_identify(
        self,
        *,
        group_id: str,
        file: FileTypes,
        top_k: Optional[int] = None,
        sample_rate: Optional[int] = None,
        channel: Optional[int] = None,
        **kwargs,
    ) -> SpeakerIdentifyResp:
        url = f"{self._base_url}/v1/audio/voiceprint_groups/{group_id}/speaker_identify"
        headers: Optional[dict] = kwargs.get("headers")
        files = {"file": _try_fix_file(file)}
        body = remove_none_values(
            {
                "top_k": top_k,
                "sample_rate": sample_rate,
                "channel": channel,
            }
        )

        return await self._requester.arequest(
            "post", url, False, cast=SpeakerIdentifyResp, headers=headers, body=body, files=files
        )



from typing import List, Optional

from cozepy.bots import PublishStatus
from cozepy.model import AsyncNumberPaged, CozeModel, NumberPaged, NumberPagedResponse
from cozepy.request import HTTPRequest, Requester
from cozepy.util import remove_none_values, remove_url_trailing_slash


class SimpleApp(CozeModel):
    id: str
    name: str
    description: str
    icon_url: str
    is_published: bool
    owner_user_id: str
    updated_at: int

    published_at: Optional[int] = None


class _PrivateListAppsData(CozeModel, NumberPagedResponse[SimpleApp]):
    items: List[SimpleApp]
    total: int

    def get_total(self) -> Optional[int]:
        return self.total

    def get_has_more(self) -> Optional[bool]:
        return None

    def get_items(self) -> List[SimpleApp]:
        return self.items


class AppsClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

    def list(
        self,
        *,
        workspace_id: str,
        publish_status: Optional[PublishStatus] = None,
        connector_id: Optional[str] = None,
        page_num: int = 1,
        page_size: int = 20,
        **kwargs,
    ) -> NumberPaged[SimpleApp]:
        """
        :param workspace_id: The ID of the workspace.
        App 所在的 workspace ID。workspace ID 是 workspace 的唯一标识。
        :param page_num: Pagination size. The default is 20, meaning that 20 data entries are returned per page.
        分页大小。默认为 20，即每页返回 20 条数据。
        :param page_size: Page number for paginated queries. The default is 1,
        meaning that the data return starts from the first page.
        分页查询时的页码。默认为 1，即从第一页数据开始返回。
        :return: Specify the list of Apps in the workspace.
        指定 workspace 的 App 列表。
        """
        url = f"{self._base_url}/v1/apps"
        headers: Optional[dict] = kwargs.get("headers")

        def request_maker(i_page_num: int, i_page_size: int) -> HTTPRequest:
            return self._requester.make_request(
                "GET",
                url,
                params=remove_none_values(
                    {
                        "workspace_id": workspace_id,
                        "page_size": i_page_size,
                        "page_index": i_page_num,
                        "publish_status": publish_status.value if publish_status else None,
                        "connector_id": connector_id,
                    }
                ),
                headers=headers,
                cast=_PrivateListAppsData,
                stream=False,
            )

        return NumberPaged(
            page_num=page_num,
            page_size=page_size,
            requestor=self._requester,
            request_maker=request_maker,
        )


class AsyncAppsClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

    async def list(
        self,
        *,
        workspace_id: str,
        publish_status: Optional[PublishStatus] = None,
        connector_id: Optional[str] = None,
        page_num: int = 1,
        page_size: int = 20,
        **kwargs,
    ) -> AsyncNumberPaged[SimpleApp]:
        """
        :param workspace_id: The ID of the workspace.
        App 所在的 workspace ID。workspace ID 是 workspace 的唯一标识。
        :param page_num: Pagination size. The default is 20, meaning that 20 data entries are returned per page.
        分页大小。默认为 20，即每页返回 20 条数据。
        :param page_size: Page number for paginated queries. The default is 1,
        meaning that the data return starts from the first page.
        分页查询时的页码。默认为 1，即从第一页数据开始返回。
        :return: Specify the list of Apps in the workspace.
        指定 workspace 的 App 列表。
        """
        url = f"{self._base_url}/v1/apps"
        headers: Optional[dict] = kwargs.get("headers")

        async def request_maker(i_page_num: int, i_page_size: int) -> HTTPRequest:
            return await self._requester.amake_request(
                "GET",
                url,
                params=remove_none_values(
                    {
                        "workspace_id": workspace_id,
                        "page_size": i_page_size,
                        "page_index": i_page_num,
                        "publish_status": publish_status.value if publish_status else None,
                        "connector_id": connector_id,
                    }
                ),
                headers=headers,
                cast=_PrivateListAppsData,
                stream=False,
            )

        return await AsyncNumberPaged.build(
            page_num=page_num,
            page_size=page_size,
            requestor=self._requester,
            request_maker=request_maker,
        )



from typing import List, Optional

from cozepy.model import CozeModel, DynamicStrEnum
from cozepy.request import Requester
from cozepy.util import dump_exclude_none, remove_url_trailing_slash


class EnterpriseMemberRole(DynamicStrEnum):
    ENTERPRISE_ADMIN = "enterprise_admin"  # 企业管理员
    ENTERPRISE_MEMBER = "enterprise_member"  # 企业成员


class EnterpriseMember(CozeModel):
    user_id: str  # 用户ID
    role: EnterpriseMemberRole  # 当前用户角色


class CreateEnterpriseMemberResp(CozeModel):
    pass


class DeleteEnterpriseMemberResp(CozeModel):
    pass


class UpdateEnterpriseMemberResp(CozeModel):
    pass


class EnterprisesMembersClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

    def create(
        self,
        *,
        enterprise_id: str,
        users: List[EnterpriseMember],
        **kwargs,
    ) -> CreateEnterpriseMemberResp:
        url = f"{self._base_url}/v1/enterprises/{enterprise_id}/members"
        headers: Optional[dict] = kwargs.get("headers")
        body = dump_exclude_none(
            {
                "users": users,
            }
        )
        return self._requester.request(
            "post", url, stream=False, cast=CreateEnterpriseMemberResp, headers=headers, body=body
        )

    def delete(
        self,
        *,
        enterprise_id: str,
        user_id: str,
        receiver_user_id: str,
        **kwargs,
    ) -> DeleteEnterpriseMemberResp:
        url = f"{self._base_url}/v1/enterprises/{enterprise_id}/members/{user_id}"
        headers: Optional[dict] = kwargs.get("headers")
        body = dump_exclude_none(
            {
                "receiver_user_id": receiver_user_id,
            }
        )
        return self._requester.request(
            "delete", url, stream=False, cast=DeleteEnterpriseMemberResp, headers=headers, body=body
        )

    def update(
        self,
        *,
        enterprise_id: str,
        user_id: str,
        role: EnterpriseMemberRole,
        **kwargs,
    ) -> UpdateEnterpriseMemberResp:
        url = f"{self._base_url}/v1/enterprises/{enterprise_id}/members/{user_id}"
        headers: Optional[dict] = kwargs.get("headers")
        body = dump_exclude_none(
            {
                "role": role,
            }
        )
        return self._requester.request(
            "put", url, stream=False, cast=UpdateEnterpriseMemberResp, headers=headers, body=body
        )


class AsyncEnterprisesMembersClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

    async def create(
        self,
        *,
        enterprise_id: str,
        users: List[EnterpriseMember],
        **kwargs,
    ) -> CreateEnterpriseMemberResp:
        url = f"{self._base_url}/v1/enterprises/{enterprise_id}/members"
        headers: Optional[dict] = kwargs.get("headers")
        body = dump_exclude_none({"users": users})
        return await self._requester.arequest(
            "post", url, stream=False, cast=CreateEnterpriseMemberResp, headers=headers, body=body
        )

    async def delete(
        self,
        *,
        enterprise_id: str,
        user_id: str,
        receiver_user_id: str,
        **kwargs,
    ) -> DeleteEnterpriseMemberResp:
        url = f"{self._base_url}/v1/enterprises/{enterprise_id}/members/{user_id}"
        headers: Optional[dict] = kwargs.get("headers")
        body = dump_exclude_none(
            {
                "receiver_user_id": receiver_user_id,
            }
        )
        return await self._requester.arequest(
            "delete", url, stream=False, cast=DeleteEnterpriseMemberResp, headers=headers, body=body
        )

    async def update(
        self,
        *,
        enterprise_id: str,
        user_id: str,
        role: EnterpriseMemberRole,
        **kwargs,
    ) -> UpdateEnterpriseMemberResp:
        url = f"{self._base_url}/v1/enterprises/{enterprise_id}/members/{user_id}"
        headers: Optional[dict] = kwargs.get("headers")
        body = dump_exclude_none(
            {
                "role": role,
            }
        )
        return await self._requester.arequest(
            "put", url, stream=False, cast=UpdateEnterpriseMemberResp, headers=headers, body=body
        )



from typing import List, Optional

from cozepy.model import CozeModel, ListResponse
from cozepy.request import Requester
from cozepy.util import remove_none_values, remove_url_trailing_slash


class VariableValue(CozeModel):
    keyword: str
    value: str
    create_time: int = 0
    update_time: int = 0


class _PrivateVariablesRetrieveData(CozeModel):
    items: List[VariableValue]


class UpdateVariableResp(CozeModel):
    pass


class VariablesClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

    def retrieve(
        self,
        *,
        connector_uid: str,
        keywords: List[str],
        app_id: Optional[str] = None,
        bot_id: Optional[str] = None,
        connector_id: Optional[str] = None,
    ) -> ListResponse[VariableValue]:
        url = f"{self._base_url}/v1/variables"
        params = remove_none_values(
            {
                "app_id": app_id,
                "bot_id": bot_id,
                "connector_id": connector_id,
                "connector_uid": connector_uid,
                "keywords": ",".join(keywords),
            }
        )
        res = self._requester.request("get", url, False, _PrivateVariablesRetrieveData, params=params)
        return ListResponse[VariableValue](raw_response=res.response._raw_response, data=res.items)

    def update(
        self,
        *,
        connector_uid: str,
        data: List[VariableValue],
        app_id: Optional[str] = None,
        bot_id: Optional[str] = None,
        connector_id: Optional[str] = None,
    ) -> UpdateVariableResp:
        url = f"{self._base_url}/v1/variables"
        body = remove_none_values(
            {
                "app_id": app_id,
                "bot_id": bot_id,
                "connector_id": connector_id,
                "connector_uid": connector_uid,
                "data": [
                    {
                        "keyword": v.keyword,
                        "value": v.value,
                    }
                    for v in data
                ],
            }
        )
        return self._requester.request(
            "put",
            url,
            False,
            cast=UpdateVariableResp,
            body=body,
        )


class AsyncVariablesClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

    async def retrieve(
        self,
        *,
        connector_uid: str,
        keywords: List[str],
        app_id: Optional[str] = None,
        bot_id: Optional[str] = None,
        connector_id: Optional[str] = None,
    ) -> ListResponse[VariableValue]:
        url = f"{self._base_url}/v1/variables"
        params = remove_none_values(
            {
                "app_id": app_id,
                "bot_id": bot_id,
                "connector_id": connector_id,
                "connector_uid": connector_uid,
                "keywords": ",".join(keywords),
            }
        )
        res = await self._requester.arequest("get", url, False, _PrivateVariablesRetrieveData, params=params)
        return ListResponse[VariableValue](raw_response=res.response._raw_response, data=res.items)

    async def update(
        self,
        *,
        connector_uid: str,
        data: List[VariableValue],
        app_id: Optional[str] = None,
        bot_id: Optional[str] = None,
        connector_id: Optional[str] = None,
    ) -> UpdateVariableResp:
        url = f"{self._base_url}/v1/variables"
        body = remove_none_values(
            {
                "app_id": app_id,
                "bot_id": bot_id,
                "connector_id": connector_id,
                "connector_uid": connector_uid,
                "data": [
                    {
                        "keyword": v.keyword,
                        "value": v.value,
                    }
                    for v in data
                ],
            }
        )
        return await self._requester.arequest(
            "put",
            url,
            False,
            cast=UpdateVariableResp,
            body=body,
        )



from typing import List, Optional

from cozepy.model import AsyncNumberPaged, CozeModel, HTTPRequest, NumberPaged
from cozepy.request import Requester
from cozepy.util import remove_none_values, remove_url_trailing_slash
from cozepy.workspaces import WorkspaceRoleType


class WorkspaceMember(CozeModel):
    user_id: str  # 用户ID
    role_type: WorkspaceRoleType  # 当前用户角色

    user_nickname: Optional[str] = None  # 昵称（添加成员时不用传）
    user_unique_name: Optional[str] = None  # 用户名（添加成员时不用传）
    avatar_url: Optional[str] = None  # 头像 （添加成员时不用传）


class CreateWorkspaceMemberResp(CozeModel):
    # 团队或企业版成功添加的用户 ID 列表。
    added_success_user_ids: List[str]
    # 个人版中，发起邀请且用户同意加入的用户 ID 列表。
    invited_success_user_ids: List[str]
    # 因用户不存在而导致添加失败的用户 ID 列表。
    not_exist_user_ids: List[str]
    # 用户在该工作空间中已经存在，不重复添加。
    already_joined_user_ids: List[str]
    # 已经发起邀请但用户还未同意加入的用户 ID 列表。
    # 仅个人版的空间添加用户时需要发出邀请，用户同意后才会加入空间。
    already_invited_user_ids: List[str]


class DeleteWorkspaceMemberResp(CozeModel):
    # 成功移除的成员列表。
    removed_success_user_ids: List[str]
    # 不在当前空间中的用户 ID 列表，这些用户不会被处理。
    not_in_workspace_user_ids: List[str]
    # 移除失败，该用户为空间所有者。
    owner_not_support_remove_user_ids: List[str]


class WorkspacesMembersClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

    def create(
        self,
        *,
        workspace_id: str,
        users: List[WorkspaceMember],
        **kwargs,
    ) -> CreateWorkspaceMemberResp:
        """批量邀请用户加入空间

        :param workspace_id: 需要添加用户的空间 ID。
        :param users: 要添加的成员列表，单次最多添加 20 个成员。
        """
        url = f"{self._base_url}/v1/workspaces/{workspace_id}/members"
        headers: Optional[dict] = kwargs.get("headers")
        body = remove_none_values(
            {
                "users": [
                    {
                        "user_id": user.user_id,
                        "role_type": user.role_type,
                    }
                    for user in users
                ],
            }
        )
        return self._requester.request(
            "post", url, stream=False, cast=CreateWorkspaceMemberResp, headers=headers, body=body
        )

    def delete(
        self,
        *,
        workspace_id: str,
        user_ids: List[str],
        **kwargs,
    ) -> DeleteWorkspaceMemberResp:
        """ "批量移除空间中的用户

        :param workspace_id: 需要移除用户的空间 ID。
        :param user_ids: 要移除的成员，单次最多移除 5 个成员。
        """
        url = f"{self._base_url}/v1/workspaces/{workspace_id}/members"
        headers: Optional[dict] = kwargs.get("headers")
        body = remove_none_values(
            {
                "user_ids": user_ids,
            }
        )
        return self._requester.request(
            "delete", url, stream=False, cast=DeleteWorkspaceMemberResp, headers=headers, body=body
        )

    def list(
        self,
        *,
        workspace_id: str,
        page_num: int = 1,
        page_size: int = 20,
        **kwargs,
    ) -> NumberPaged[WorkspaceMember]:
        """查看空间成员列表

        :param workspace_id: 需要查看成员列表的空间 ID。
        :param page_num: 分页查询时的页码。最小值为 1，默认为 1，即从第一页数据开始返回。
        :param page_size: 分页大小。取值范围为 1~50，默认为 20。
        :return: 空间成员列表。
        """
        url = f"{self._base_url}/v1/workspaces/{workspace_id}/members"
        headers: Optional[dict] = kwargs.get("headers")

        def request_maker(i_page_num: int, i_page_size: int) -> HTTPRequest:
            return self._requester.make_request(
                "GET",
                url,
                headers=headers,
                params=remove_none_values(
                    {
                        "page_size": i_page_size,
                        "page_num": i_page_num,
                    }
                ),
                cast=WorkspaceMember,
                stream=False,
            )

        return NumberPaged(
            page_num=page_num,
            page_size=page_size,
            requestor=self._requester,
            request_maker=request_maker,
        )


class AsyncWorkspacesMembersClient(object):
    def __init__(self, base_url: str, requester: Requester):
        self._base_url = remove_url_trailing_slash(base_url)
        self._requester = requester

    async def create(
        self,
        *,
        workspace_id: str,
        users: List[WorkspaceMember],
        **kwargs,
    ) -> CreateWorkspaceMemberResp:
        """批量邀请用户加入空间

        :param workspace_id: 需要添加用户的空间 ID。
        :param users: 要添加的成员列表，单次最多添加 20 个成员。
        """
        url = f"{self._base_url}/v1/workspaces/{workspace_id}/members"
        headers: Optional[dict] = kwargs.get("headers")
        body = remove_none_values(
            {
                "users": [
                    {
                        "user_id": user.user_id,
                        "role_type": user.role_type,
                    }
                    for user in users
                ],
            }
        )
        return await self._requester.arequest(
            "post", url, stream=False, cast=CreateWorkspaceMemberResp, headers=headers, body=body
        )

    async def delete(
        self,
        *,
        workspace_id: str,
        user_ids: List[str],
        **kwargs,
    ) -> DeleteWorkspaceMemberResp:
        """ "批量移除空间中的用户

        :param workspace_id: 需要移除用户的空间 ID。
        :param user_ids: 要移除的成员，单次最多移除 5 个成员。
        """
        url = f"{self._base_url}/v1/workspaces/{workspace_id}/members"
        headers: Optional[dict] = kwargs.get("headers")
        body = remove_none_values(
            {
                "user_ids": user_ids,
            }
        )
        return await self._requester.arequest(
            "delete", url, stream=False, cast=DeleteWorkspaceMemberResp, headers=headers, body=body
        )

    async def list(
        self,
        *,
        workspace_id: str,
        page_num: int = 1,
        page_size: int = 20,
        **kwargs,
    ) -> AsyncNumberPaged[WorkspaceMember]:
        """查看空间成员列表

        :param workspace_id: 需要查看成员列表的空间 ID。
        :param page_num: 分页查询时的页码。最小值为 1，默认为 1，即从第一页数据开始返回。
        :param page_size: 分页大小。取值范围为 1~50，默认为 20。
        :return: 空间成员列表。
        """
        url = f"{self._base_url}/v1/workspaces/{workspace_id}/members"
        headers: Optional[dict] = kwargs.get("headers")

        async def request_maker(i_page_num: int, i_page_size: int) -> HTTPRequest:
            return await self._requester.amake_request(
                "GET",
                url,
                headers=headers,
                params=remove_none_values(
                    {
                        "page_size": i_page_size,
                        "page_num": i_page_num,
                    }
                ),
                cast=WorkspaceMember,
                stream=False,
            )

        return await AsyncNumberPaged.build(
            page_num=page_num,
            page_size=page_size,
            requestor=self._requester,
            request_maker=request_maker,
        )
